
# Enum: CausalPredicateEnum

A term describing the causal relationship between two activities. All terms are drawn from the "causally upstream or within" (RO:0002418) branch of the Relation Ontology (RO).

URI: [gocam:CausalPredicateEnum](https://w3id.org/gocam/CausalPredicateEnum)


## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| causally upstream of, positive effect |  | RO:0002304 |  |
| causally upstream of, negative effect |  | RO:0002305 |  |
| causally upstream of |  | RO:0002411 |  |
| immediately causally upstream of |  | RO:0002412 |  |
| causally upstream of or within |  | RO:0002418 |  |
| causally upstream of or within, negative effect |  | RO:0004046 |  |
| causally upstream of or within, positive effect |  | RO:0004047 |  |
| regulates |  | RO:0002211 |  |
| negatively regulates |  | RO:0002212 |  |
| positively regulates |  | RO:0002213 |  |
| provides input for |  | RO:0002413 |  |
| removes input for |  | RO:0012010 |  |
